==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/button/interactive/InteractiveCollectionSpec.java <==
package it.auties.whatsapp.model.button.interactive;

import it.auties.whatsapp.model.button.interactive.InteractiveCollection;
import it.auties.protobuf.stream.ProtobufInputStream;
import it.auties.protobuf.stream.ProtobufOutputStream;

public class InteractiveCollectionSpec {
    public static byte[] encode(InteractiveCollection protoInputObject) {
      if(protoInputObject == null) {
         return null;
      }
      var outputStream = new ProtobufOutputStream();
var business = protoInputObject.business();
if(business != null) {
var business0 = business.toProtobufValue();
if(business0 != null) {
outputStream.writeString(1, business0);
}
}
outputStream.writeString(2, protoInputObject.id());
outputStream.writeInt32(3, protoInputObject.version());
      return outputStream.toByteArray();
    }

    public static InteractiveCollection decode(byte[] input) {
        if(input == null) {
            return null;
        }
        var inputStream = new ProtobufInputStream(input);
        it.auties.whatsapp.model.jid.Jid business = null;
        java.lang.String id = null;
        int version = 0;
        while(inputStream.readTag()) {
            switch(inputStream.index()) {
                case 1 -> business = it.auties.whatsapp.model.jid.Jid.ofProtobuf(inputStream.readString());
                case 2 -> id = inputStream.readString();
                case 3 -> version = inputStream.readInt32();
                default -> inputStream.skipBytes();
            }
        }
        return new it.auties.whatsapp.model.button.interactive.InteractiveCollection(business, id, version);
    }

}

==> cobalt-0.0.4-sources.jar: it/auties/whatsapp/model/button/interactive/InteractiveCollectionSpec.java <==
package it.auties.whatsapp.model.button.interactive;

import it.auties.whatsapp.model.button.interactive.InteractiveCollection;
import it.auties.protobuf.stream.ProtobufInputStream;
import it.auties.protobuf.stream.ProtobufOutputStream;

public class InteractiveCollectionSpec {
    public static byte[] encode(InteractiveCollection protoInputObject) {
      if(protoInputObject == null) {
         return null;
      }
      var outputStream = new ProtobufOutputStream();
var business = protoInputObject.business();
if(business != null) {
var business0 = business.toString();
if(business0 != null) {
outputStream.writeString(1, business0);
}
}
outputStream.writeString(2, protoInputObject.id());
outputStream.writeInt32(3, protoInputObject.version());
      return outputStream.toByteArray();
    }

    public static InteractiveCollection decode(byte[] input) {
        if(input == null) {
            return null;
        }
        var inputStream = new ProtobufInputStream(input);
        it.auties.whatsapp.model.jid.Jid business = null;
        java.lang.String id = null;
        int version = 0;
        while(inputStream.readTag()) {
            switch(inputStream.index()) {
                case 1 -> business = it.auties.whatsapp.model.jid.Jid.ofProtobuf(inputStream.readString());
                case 2 -> id = inputStream.readString();
                case 3 -> version = inputStream.readInt32();
                default -> inputStream.skipBytes();
            }
        }
        return new it.auties.whatsapp.model.button.interactive.InteractiveCollection(business, id, version);
    }

}
